<?php

/*-----------------------------------------------------------------------------------*/
/* Enqueu scripts */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('blanco_lite_enqueue_scripts')) {

	function blanco_lite_enqueue_scripts() {

		wp_deregister_style( 'savana-lite-style' );
		wp_deregister_style( 'savana-lite-' . esc_attr(get_theme_mod('savana_lite_skin', 'orange')) );

		wp_enqueue_style( 'blanco-lite-parent-style' , get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'blanco-lite-style' , get_stylesheet_directory_uri() . '/style.css' );

		wp_enqueue_style(
			'blanco-lite-' . esc_attr(get_theme_mod('savana_lite_skin', 'orange')),
			get_stylesheet_directory_uri() . '/assets/skins/' . esc_attr(get_theme_mod('savana_lite_skin', 'orange')) . '.css',
			array( 'blanco-lite-style' ),
			'1.0.0'
		);
		
		wp_enqueue_script(
			'blanco-lite-script',
			get_stylesheet_directory_uri() . '/assets/js/script.js',
			array('jquery'),
			'1.0.0',
			TRUE
		);

	}

	add_action( 'wp_enqueue_scripts', 'blanco_lite_enqueue_scripts', 998);

}

/*-----------------------------------------------------------------------------------*/
/* Replace hooks */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('blanco_lite_replace_hooks')) {

	function blanco_lite_replace_hooks() {

		remove_action( 'savana_lite_slick_slider', 'savana_lite_slick_slider_function');
		remove_action( 'savana_lite_default_format', 'savana_lite_default_format_function' );
		remove_action( 'savana_lite_image_format', 'savana_lite_image_format_function' );
		remove_action( 'savana_lite_page_format', 'savana_lite_page_format_function' );
		remove_action( 'savana_lite_before_content', 'savana_lite_before_content_function' );
	
	}

	add_action('init','blanco_lite_replace_hooks');

}

/*-----------------------------------------------------------------------------------*/
/* Theme setup */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('blanco_lite_theme_setup')) {

	function blanco_lite_theme_setup() {

		load_child_theme_textdomain( 'blanco-lite', get_stylesheet_directory() . '/languages' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/functions/function-style.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post-formats/default-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post-formats/image-format.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post-formats/page-format.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/before-content.php' );

		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/post/related-post.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/related-posts.php' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'core/templates/homepage-slider.php' );

		if ( !get_theme_mod('savana_lite_logo_text_color') )
			set_theme_mod( 'savana_lite_logo_text_color', '#616161' );

	}

	add_action( 'after_setup_theme', 'blanco_lite_theme_setup', 999);

}

/*-----------------------------------------------------------------------------------*/
/* Customize register */
/*-----------------------------------------------------------------------------------*/

if (!function_exists('blanco_lite_customize_register')) {

	function blanco_lite_customize_register( $wp_customize ) {

		$wp_customize->remove_control('savana_lite_enable_slideshow_overlay');

		$wp_customize->add_setting( 'blanco_lite_enable_related_posts', array(
			'default' => 'on',
			'sanitize_callback' => 'blanco_lite_checkbox_sanize',
		));

		$wp_customize->add_control( 'blanco_lite_enable_related_posts' , array(
			'type' => 'checkbox',
			'section' => 'settings_section',
			'label' => esc_html__('Related posts','blanco-lite'),
			'description' => esc_html__('Do you want to display the related posts at the end of each article?','blanco-lite'),
		));

		function blanco_lite_checkbox_sanize ($input) {

			return $input ? true : false;

		}

	}

	add_action( 'customize_register', 'blanco_lite_customize_register', 11 );

}

?>
